@@ -8,11 +8,15 @@ from pathlib import Path
 import sys
 
 from schematics.exceptions import ValidationError
-from schematics.types import ListType, ModelType, StringType
+from schematics.types import (
+    BaseType, DictType, ListType, ModelType, StringType, URLType
+)
 from schematics import Model
 
 from hidebound.core.specification_base import SpecificationBase
 from hidebound.exporters.girder_exporter import GirderConfig
+from hidebound.exporters.local_disk_exporter import LocalDiskConfig
+from hidebound.exporters.s3_exporter import S3Config
 import hidebound.core.validators as vd
 # ------------------------------------------------------------------------------
 
@@ -93,6 +97,30 @@ def is_hidebound_directory(directory):
     if Path(directory).name != 'hidebound':
         msg = f'{directory} directory is not named hidebound.core.'
         raise ValidationError(msg)
+
+
+def is_http_method(method):
+    # type: (str) -> None
+    '''
+    Ensures given method is a legal HTTP method.
+    Legal methods include:
+
+        * get
+        * put
+        * post
+        * delete
+        * patch
+
+    Args:
+        method (str): HTTP method.
+
+    Raises:
+        ValidationError: If method is not a legal HTTP method.
+    '''
+    methods = ['get', 'put', 'post', 'delete', 'patch']
+    if method not in methods:
+        msg = f'{method} is not a legal HTTP method. Legal methods: {methods}.'
+        raise ValidationError(msg)
 # ------------------------------------------------------------------------------
 
 
@@ -111,7 +139,7 @@ class Config(Model):
         exclude_regex (str, optional): Exclude filenames that match this regex.
             Default: '\.DS_Store'.
         write_mode (str, optional): How assets will be extracted to
-            hidebound/data directory. Default: copy.
+            hidebound/content directory. Default: copy.
         exporters (dict, optional): Dictionary of exporter configs, where the
             key is the exporter name and the value is its config. Default: {}.
     '''
@@ -135,5 +163,22 @@ class Config(Model):
     )  # type: StringType
 
     class ExportersConfig(Model):
-        girder = ModelType(GirderConfig, required=False, default=None)  # type: ModelType
+        girder = ModelType(
+            GirderConfig, required=False, serialize_when_none=False
+        )  # type: ModelType
+        s3 = ModelType(
+            S3Config, required=False, serialize_when_none=False
+        )  # type: ModelType
+        local_disk = ModelType(
+            LocalDiskConfig, required=False, serialize_when_none=False
+        )  # type: ModelType
     exporters = ModelType(ExportersConfig, required=False, default={})  # type: ModelType
+
+    class WebhookConfig(Model):
+        url = URLType(required=True)  # type: URLType
+        method = StringType(required=True, validators=[is_http_method])  # type: StringType
+        headers = DictType(StringType, required=False)  # type: DictType
+        data = DictType(BaseType, required=False, serialize_when_none=False)  # type: DictType
+        json = DictType(BaseType, required=False, serialize_when_none=False)  # type: DictType
+        params = DictType(BaseType, required=False, serialize_when_none=False)  # type: DictType
+    webhooks = ListType(ModelType(WebhookConfig), required=False, default=[])  # type: ListType
