@@ -4,19 +4,26 @@ from copy import deepcopy
 from importlib import import_module
 from pathlib import Path
 import json
+import logging
 import os
 import shutil
 import sys
 
 from pandas import DataFrame
-import pandasql
+import jsoncomment as jsonc
 import numpy as np
+import pandasql
+import requests
 
 from hidebound.core.config import Config
 from hidebound.core.specification_base import SpecificationBase
 from hidebound.exporters.girder_exporter import GirderExporter
+from hidebound.exporters.local_disk_exporter import LocalDiskExporter
+from hidebound.exporters.s3_exporter import S3Exporter
 import hidebound.core.database_tools as db_tools
 import hidebound.core.tools as tools
+
+LOGGER = logging.getLogger(__name__)
 # ------------------------------------------------------------------------------
 
 
@@ -67,6 +74,7 @@ class Database:
             exclude_regex=config['exclude_regex'],
             write_mode=config['write_mode'],
             exporters=config['exporters'],
+            webhooks=config['webhooks'],
         )
 
     @staticmethod
@@ -82,7 +90,7 @@ class Database:
             Database: Database instance.
         '''
         with open(filepath) as f:
-            config = json.load(f)
+            config = jsonc.JsonComment().load(f)
         return Database.from_config(config)
 
     def __init__(
@@ -94,8 +102,9 @@ class Database:
         exclude_regex=r'\.DS_Store',
         write_mode='copy',
         exporters={},
+        webhooks=[],
     ):
-        # type: (Union[str, Path], Union[str, Path], List[SpecificationBase], str, str, str, Dict[str, Any]) -> None  # noqa E501
+        # type: (Union[str, Path], Union[str, Path], List[SpecificationBase], str, str, str, Dict[str, Any], List[Dict]) -> None  # noqa E501
         r'''
         Creates an instance of Database but does not populate it with data.
 
@@ -110,10 +119,12 @@ class Database:
             exclude_regex (str, optional): Exclude filenames that match this
                 regex. Default: '\.DS_Store'.
             write_mode (str, optional): How assets will be extracted to
-                hidebound/data directory. Default: copy.
+                hidebound/content directory. Default: copy.
             exporters (dict, optional): Dictionary of exporter configs, where
                 the key is the exporter name and the value is its config.
                 Default: {}.
+            webhooks (list[dict], optional): List of webhooks to call.
+                Default: [].
 
         Raises:
             TypeError: If specifications contains a non-SpecificationBase
@@ -165,6 +176,7 @@ class Database:
         self._specifications = {x.__name__.lower(): x for x in specifications} \
             # type: Dict[str, SpecificationBase]
         self._exporters = exporters
+        self._webhooks = webhooks
         self.data = None
 
         # needed for testing
@@ -178,7 +190,8 @@ class Database:
 
         Writes:
 
-            * file data to hb_parent/hidebound/data - under same directory structure
+            * file content to hb_parent/hidebound/content - under same directory
+                                                            structure
             * file metadata as json to hb_parent/hidebound/metadata/file
             * asset metadata as json to hb_parent/hidebound/metadata/asset
 
@@ -211,6 +224,7 @@ class Database:
         # write file data
         if self._write_mode == 'move':
             file_data.apply(lambda x: shutil.move(x.source, x.target), axis=1)
+            tools.delete_empty_directories(self._root)
         else:
             file_data.apply(lambda x: shutil.copy2(x.source, x.target), axis=1)
 
@@ -270,9 +284,11 @@ class Database:
         # find columns by legal type
         cols = self.data.columns.tolist()
         if len(self.data) > 0:
-            cols = data.applymap(type).apply(lambda x: set(x.unique()))
+            cols = data \
+                .applymap(type) \
+                .apply(lambda x: x.unique().tolist())
             legal_cols = set([int, float, str, bool, None])
-            mask = cols.apply(lambda x: x.difference(legal_cols) == set())
+            mask = cols.apply(lambda x: set(x).difference(legal_cols) == set())
             cols = cols[mask].index.tolist()
 
         # nicely order columns
@@ -335,13 +351,13 @@ class Database:
     def delete(self):
         # type: () -> "Database"
         '''
-        Deletes hidebound/data and hidebound/metadata directories and all their
+        Deletes hidebound/content and hidebound/metadata directories and all their
         contents.
 
         Returns:
             Database: self.
         '''
-        data_dir = Path(self._hb_root, 'data')
+        data_dir = Path(self._hb_root, 'content')
         if data_dir.exists():
             shutil.rmtree(data_dir)
 
@@ -351,26 +367,64 @@ class Database:
 
         return self
 
+    def call_webhooks(self):
+        # type () -> requests.Response
+        '''
+        Calls webhooks defined in config.
+
+        Yields:
+            requests.Response: Webhook response.
+        '''
+        for hook in self._webhooks:
+            url = hook['url']
+            headers = hook.get('headers', None)
+            method = hook['method']
+
+            kwargs = {}
+            if 'data' in hook and method in ['post', 'put', 'patch']:
+                kwargs['data'] = json.dumps(hook['data']).encode()
+
+            if 'json' in hook and method == 'post':
+                kwargs['json'] = hook['json']
+
+            if 'params' in hook and method == 'get':
+                kwargs['params'] = hook['params']
+
+            method = getattr(requests, method)
+            yield method(url, headers=headers, **kwargs)
+
     def export(self):
         # type: () -> None
         '''
         Exports all the files found in in hidebound root directory.
+        Calls webhooks afterwards.
         '''
         # TODO: Find a nicer pattern for injecting exporters.
-        lut = dict(girder=GirderExporter)
+        lut = dict(
+            girder=GirderExporter,
+            local_disk=LocalDiskExporter,
+            s3=S3Exporter,
+        )  # type: Dict[str, Any]
 
         # reassign lut for testing
         if self.__exporter_lut is not None:
             lut = self.__exporter_lut
 
-        for key, config in self._exporters.items():
+        # always run exporters in this order
+        order = ['local_disk', 's3', 'girder']
+        items = sorted(self._exporters.items(), key=lambda x: order.index(x[0]))
+
+        for key, config in items:
             exporter = lut[key].from_config(config)
             exporter.export(self._hb_root)
 
-            # assign instance tp exporter_lut for testing
+            # assign instance to exporter_lut for testing
             if self.__exporter_lut is not None:
                 self.__exporter_lut[key] = exporter
 
+        for response in self.call_webhooks():
+            LOGGER.info(response.content)  # pragma: no cover
+
     def search(self, query, group_by_asset=False):
         # type: (str, bool) -> "DataFrame"
         '''
