@@ -49,14 +49,14 @@ class SpecificationBase(Model):
     ]  # type: List[str]
     asset_name_fields = ['project', 'specification', 'descriptor', 'version']  # type: List[str]
     project = ListType(
-        StringType(), required=True, validators=[vd.is_project]
+        StringType(), required=False, validators=[vd.is_project]
     )  # type: ListType
     specification = ListType(StringType())  # type: ListType
     descriptor = ListType(
-        StringType(), required=True, validators=[vd.is_descriptor]
+        StringType(), required=False, validators=[vd.is_descriptor]
     )  # type: ListType
     version = ListType(
-        IntType(), required=True, validators=[vd.is_version]
+        IntType(), required=False, validators=[vd.is_version]
     )  # type: ListType
     extension = ListType(
         StringType(), required=True, validators=[vd.is_extension]
@@ -267,7 +267,7 @@ class SpecificationBase(Model):
             list[str]: List of filepaths.
         '''
         filepaths = []
-        for i, _ in enumerate(self.specification):
+        for i, _ in enumerate(self.extension):
             fields = set(self.asset_name_fields).union(self.filename_fields)  # type: Any
             fields = {k: getattr(self, k)[i] for k in fields}
             filepath = pattern.format(**fields)
