@@ -1,8 +1,9 @@
 from typing import Dict, Union
 
 from pathlib import Path
-import json
 import os
+
+import jsoncomment as jsonc
 # ------------------------------------------------------------------------------
 
 
@@ -14,7 +15,7 @@ class ExporterBase:
         # type: (Union[str, Path]) -> None
         '''
         Ensure the following directory exist under given hidebound directory.
-            * data
+            * content
             * metadata
             * metadata/asset
             * metadata/file
@@ -25,7 +26,7 @@ class ExporterBase:
         Raises:
             FileNotFoundError: If any of the directories have not been found.
         '''
-        data = Path(hidebound_dir, 'data')
+        data = Path(hidebound_dir, 'content')
         meta = Path(hidebound_dir, 'metadata')
         asset_dir = Path(meta, 'asset')
         file_dir = Path(meta, 'file')
@@ -51,7 +52,7 @@ class ExporterBase:
             # export asset
             asset = Path(asset_dir, asset)
             with open(asset) as f:
-                asset_meta = json.load(f)
+                asset_meta = jsonc.JsonComment().load(f)
             self._export_asset(asset_meta)
 
             # export files
@@ -60,7 +61,7 @@ class ExporterBase:
             for filepath in filepaths:
                 filepath = Path(file_dir, filepath)
                 with open(filepath) as f:
-                    file_meta = json.load(f)
+                    file_meta = jsonc.JsonComment().load(f)
                 self._export_file(file_meta)
 
     def _export_asset(self, metadata):
