@@ -78,7 +78,7 @@ def api():
         dict(
             name='write_mode',
             type='string',
-            description='How assets will be extracted to hidebound/data directory.',
+            description='How assets will be extracted to hidebound/content directory.',
             required=False,
             default='copy',
             enum=['copy', 'move'],
@@ -119,7 +119,7 @@ def initialize():
         write_mode='copy',
     )
 
-    temp = flask.request.get_json()
+    temp = flask.request.get_json()  # type: Any
     try:
         temp = json.loads(temp)
     except (JSONDecodeError, TypeError):
@@ -395,7 +395,7 @@ def search():
     global DATABASE
     global CONFIG
 
-    params = flask.request.get_json()
+    params = flask.request.get_json()  # type: Any
     grp = False
     try:
         params = json.loads(params)
