@@ -25,7 +25,7 @@ Hidebound service used for displaying and interacting with Hidebound database.
 '''
 
 
-APP = flask.Flask(__name__)  # type: Union[flask.Flask, dash.Dash]
+APP = flask.Flask('hidebound')  # type: Union[flask.Flask, dash.Dash]
 swg.Swagger(APP)
 APP.register_blueprint(api.API)
 APP = components.get_dash_app(APP)
@@ -104,37 +104,42 @@ def on_event(*inputs):
 
     input_id = context.triggered[0]['prop_id'].split('.')[0]
 
+    server = APP.server  # type: ignore
     if input_id == 'init-button':
-        APP.server.test_client().post('/api/initialize', json=conf)
+        response = server.test_client().post('/api/initialize', json=conf).json
+        if 'error' in response.keys():
+            store['/api/read'] = response
 
     elif input_id == 'update-button':
         if api.DATABASE is None:
-            APP.server.test_client().post('/api/initialize', json=conf)
+            response = server.test_client().post('/api/initialize', json=conf).json
+            if 'error' in response.keys():
+                store['/api/read'] = response
 
-        APP.server.test_client().post('/api/update')
+        server.test_client().post('/api/update')
 
         params = json.dumps({'group_by_asset': grp})
-        response = APP.server.test_client().post('/api/read', json=params).json
+        response = server.test_client().post('/api/read', json=params).json
         store['/api/read'] = response
 
     elif input_id == 'create-button':
-        APP.server.test_client().post('/api/create')
+        server.test_client().post('/api/create')
 
     elif input_id == 'export-button':
-        response = APP.server.test_client().post('/api/export')
+        response = server.test_client().post('/api/export')
         code = response.status_code
         if code < 200 or code >= 300:
             store['/api/read'] = response.json
 
     elif input_id == 'delete-button':
-        APP.server.test_client().post('/api/delete')
+        server.test_client().post('/api/delete')
 
     elif input_id == 'search-button':
         query = json.dumps({
             'query': inputs_['query'],
             'group_by_asset': inputs_['dropdown']
         })
-        response = APP.server.test_client().post('/api/search', json=query).json
+        response = server.test_client().post('/api/search', json=query).json
         store['/api/read'] = response
         store['query'] = inputs_['query']
 
@@ -291,15 +296,19 @@ def on_config_card_update(timestamp, store):
 
 if __name__ == '__main__':
     debug = 'DEBUG_MODE' in os.environ.keys()
+    config_path = None  # type: Any
     if debug:
         config, config_path = server_tools\
             .setup_hidebound_directory(
                 '/tmp',
-                config_path='/root/hidebound/resources/test_config.json'
+                config_path='/home/ubuntu/hidebound/resources/test_config.json'
             )
     else:
-        config, config_path = server_tools\
-            .setup_hidebound_directory('/mnt/storage')
+        config_path = '/mnt/storage/hidebound/config/hidebound_config.json'
+        if not Path(config_path).is_file():
+            config_path = None
+        config, config_path = server_tools \
+            .setup_hidebound_directory('/mnt/storage', config_path=config_path)
     api.CONFIG = config
     CONFIG_PATH = config_path
-    APP.run_server(debug=debug, host='0.0.0.0', port=5000)
+    APP.run_server(debug=debug, host='0.0.0.0', port=8080)
