@@ -75,7 +75,6 @@ def get_dash_app(server, storage_type='memory'):
         'background': COLOR_SCHEME['bg'],
         'color': COLOR_SCHEME['light1'],
         'border': '0px',
-        'min-width': '200px',
     }
     tab_selected_style = {
         'padding': '4px',
@@ -133,12 +132,24 @@ def get_dash_app(server, storage_type='memory'):
             )
         ],
     )
-    content = html.Div(id='content', className='content')
+    content = dcc.Loading(
+        id="content",
+        className='content',
+        type="dot",
+        style={
+            'align-items': 'center',
+            'opacity': '50%',
+            'background': COLOR_SCHEME['bg'],
+        },
+        fullscreen=True,
+        color=COLOR_SCHEME['cyan2'],
+    )
 
     app = dash.Dash(
-        __name__,
+        name='hidebound',
+        title='Hidebound',
         server=server,
-        external_stylesheets=['http://0.0.0.0:5000/static/style.css'],
+        external_stylesheets=['/static/style.css'],
     )
     app.layout = html.Div(id='layout', children=[store, tabs, content])
     app.config['suppress_callback_exceptions'] = True
@@ -198,7 +209,9 @@ def get_searchbar(query=None):
         className='col query',
         value=query,
         placeholder='SQL query that uses "FROM data"',
-        type='text'
+        type='text',
+        autoFocus=True,
+        debounce=True
     )
     dropdown = get_dropdown(['file', 'asset'])
 
@@ -263,7 +276,7 @@ def get_dummy_elements():
 def get_configbar(config):
     # type: (Dict) -> html.Div
     '''
-    Get a row of elements used for configuring hidebound.core.
+    Get a row of elements used for configuring Hidebound.
 
     Args:
         config (dict): Configuration to be displayed.
@@ -440,6 +453,8 @@ def get_datatable(data):
         data=data,
         columns=cols,
         id='datatable',
+        cell_selectable=False,
+        editable=False,
         css=[
             {
                 'selector': '.dash-cell div.dash-cell-value',
